@@ -15,8 +15,20 @@ class Transaction:
     """
     Superclass for various transaction types.
     """
-    def __init__(self, sender, fee, first, last, note, gen, gh, lease,
-                 txn_type, rekey_to):
+
+    def __init__(
+        self,
+        sender,
+        fee,
+        first,
+        last,
+        note,
+        gen,
+        gh,
+        lease,
+        txn_type,
+        rekey_to,
+    ):
         self.sender = sender
         self.fee = fee
         self.first_valid_round = first
@@ -81,7 +93,7 @@ class Transaction:
         private_key = base64.b64decode(private_key)
         txn = encoding.msgpack_encode(self)
         to_sign = constants.txid_prefix + base64.b64decode(txn)
-        signing_key = SigningKey(private_key[:constants.key_len_bytes])
+        signing_key = SigningKey(private_key[: constants.key_len_bytes])
         signed = signing_key.sign(to_sign)
         sig = signed.signature
         return sig
@@ -93,7 +105,8 @@ class Transaction:
 
     def dictify(self):
         d = dict()
-        if self.fee: d["fee"] = self.fee
+        if self.fee:
+            d["fee"] = self.fee
         if self.first_valid_round:
             d["fv"] = self.first_valid_round
         if self.genesis_id:
@@ -125,7 +138,9 @@ class Transaction:
             "gen": d["gen"] if "gen" in d else None,
             "flat_fee": True,
             "lease": d["lx"] if "lx" in d else None,
-            "rekey_to": encoding.encode_address(d["rekey"]) if "rekey" in d else None,
+            "rekey_to": encoding.encode_address(d["rekey"])
+            if "rekey" in d
+            else None,
         }
         txn_type = d["type"]
         if not isinstance(d["type"], str):
@@ -150,21 +165,23 @@ class Transaction:
         return txn
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                Transaction,
-                future.transaction.Transaction)):
+        if not isinstance(
+            other, (Transaction, future.transaction.Transaction)
+        ):
             return False
-        return (self.sender == other.sender and
-                self.fee == other.fee and
-                self.first_valid_round == other.first_valid_round and
-                self.last_valid_round == other.last_valid_round and
-                self.genesis_hash == other.genesis_hash and
-                self.genesis_id == other.genesis_id and
-                self.note == other.note and
-                self.group == other.group and
-                self.lease == other.lease and
-                self.type == other.type and
-                self.rekey_to == other.rekey_to)
+        return (
+            self.sender == other.sender
+            and self.fee == other.fee
+            and self.first_valid_round == other.first_valid_round
+            and self.last_valid_round == other.last_valid_round
+            and self.genesis_hash == other.genesis_hash
+            and self.genesis_id == other.genesis_id
+            and self.note == other.note
+            and self.group == other.group
+            and self.lease == other.lease
+            and self.type == other.type
+            and self.rekey_to == other.rekey_to
+        )
 
 
 class PaymentTxn(Transaction):
@@ -173,7 +190,7 @@ class PaymentTxn(Transaction):
 
     Args:
         sender (str): address of the sender
-        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true, 
+        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true,
             fee may fall to zero but a group of N atomic transactions must
             still have a fee of at least N*min_txn_fee.
         first (int): first round for which the transaction is valid
@@ -208,11 +225,35 @@ class PaymentTxn(Transaction):
         rekey_to (str)
     """
 
-    def __init__(self, sender, fee, first, last, gh, receiver, amt,
-                 close_remainder_to=None, note=None, gen=None, flat_fee=False,
-                 lease=None, rekey_to=None):
-        Transaction.__init__(self,  sender, fee, first, last, note, gen, gh,
-                             lease, constants.payment_txn, rekey_to)
+    def __init__(
+        self,
+        sender,
+        fee,
+        first,
+        last,
+        gh,
+        receiver,
+        amt,
+        close_remainder_to=None,
+        note=None,
+        gen=None,
+        flat_fee=False,
+        lease=None,
+        rekey_to=None,
+    ):
+        Transaction.__init__(
+            self,
+            sender,
+            fee,
+            first,
+            last,
+            note,
+            gen,
+            gh,
+            lease,
+            constants.payment_txn,
+            rekey_to,
+        )
         if receiver:
             self.receiver = receiver
         else:
@@ -222,8 +263,9 @@ class PaymentTxn(Transaction):
             raise error.WrongAmountType
         self.close_remainder_to = close_remainder_to
         if not flat_fee:
-            self.fee = max(self.estimate_size()*self.fee,
-                           constants.min_txn_fee)
+            self.fee = max(
+                self.estimate_size() * self.fee, constants.min_txn_fee
+            )
 
     def dictify(self):
         d = dict()
@@ -231,7 +273,7 @@ class PaymentTxn(Transaction):
             d["amt"] = self.amt
         if self.close_remainder_to:
             d["close"] = encoding.decode_address(self.close_remainder_to)
-        
+
         decoded_receiver = encoding.decode_address(self.receiver)
         if any(decoded_receiver):
             d["rcv"] = encoding.decode_address(self.receiver)
@@ -244,23 +286,25 @@ class PaymentTxn(Transaction):
     @staticmethod
     def _undictify(d):
         args = {
-            "close_remainder_to": encoding.encode_address(
-                d["close"]) if "close" in d else None,
+            "close_remainder_to": encoding.encode_address(d["close"])
+            if "close" in d
+            else None,
             "amt": d["amt"] if "amt" in d else 0,
-            "receiver": encoding.encode_address(
-                d["rcv"]) if "rcv" in d else None
+            "receiver": encoding.encode_address(d["rcv"])
+            if "rcv" in d
+            else None,
         }
         return args
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                PaymentTxn,
-                future.transaction.PaymentTxn)):
+        if not isinstance(other, (PaymentTxn, future.transaction.PaymentTxn)):
             return False
-        return (super(PaymentTxn, self).__eq__(other) and
-                self.receiver == other.receiver and
-                self.amt == other.amt and
-                self.close_remainder_to == other.close_remainder_to)
+        return (
+            super(PaymentTxn, self).__eq__(other)
+            and self.receiver == other.receiver
+            and self.amt == other.amt
+            and self.close_remainder_to == other.close_remainder_to
+        )
 
 
 class KeyregTxn(Transaction):
@@ -269,7 +313,7 @@ class KeyregTxn(Transaction):
 
     Args:
         sender (str): address of sender
-        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true, 
+        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true,
             fee may fall to zero but a group of N atomic transactions must
             still have a fee of at least N*min_txn_fee.
         first (int): first round for which the transaction is valid
@@ -307,19 +351,46 @@ class KeyregTxn(Transaction):
         rekey_to (str)
     """
 
-    def __init__(self, sender, fee, first, last, gh, votekey, selkey, votefst,
-                 votelst, votekd, note=None, gen=None, flat_fee=False,
-                 lease=None, rekey_to=None):
-        Transaction.__init__(self, sender, fee, first, last, note, gen, gh,
-                             lease, constants.keyreg_txn, rekey_to)
+    def __init__(
+        self,
+        sender,
+        fee,
+        first,
+        last,
+        gh,
+        votekey,
+        selkey,
+        votefst,
+        votelst,
+        votekd,
+        note=None,
+        gen=None,
+        flat_fee=False,
+        lease=None,
+        rekey_to=None,
+    ):
+        Transaction.__init__(
+            self,
+            sender,
+            fee,
+            first,
+            last,
+            note,
+            gen,
+            gh,
+            lease,
+            constants.keyreg_txn,
+            rekey_to,
+        )
         self.votepk = votekey
         self.selkey = selkey
         self.votefst = votefst
         self.votelst = votelst
         self.votekd = votekd
         if not flat_fee:
-            self.fee = max(self.estimate_size()*self.fee,
-                           constants.min_txn_fee)
+            self.fee = max(
+                self.estimate_size() * self.fee, constants.min_txn_fee
+            )
 
     def dictify(self):
         d = {
@@ -327,7 +398,7 @@ class KeyregTxn(Transaction):
             "votefst": self.votefst,
             "votekd": self.votekd,
             "votekey": encoding.decode_address(self.votepk),
-            "votelst": self.votelst
+            "votelst": self.votelst,
         }
         d.update(super(KeyregTxn, self).dictify())
         od = OrderedDict(sorted(d.items()))
@@ -341,21 +412,21 @@ class KeyregTxn(Transaction):
             "selkey": encoding.encode_address(d["selkey"]),
             "votefst": d["votefst"],
             "votelst": d["votelst"],
-            "votekd": d["votekd"]
+            "votekd": d["votekd"],
         }
         return args
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                KeyregTxn,
-                future.transaction.KeyregTxn)):
+        if not isinstance(other, (KeyregTxn, future.transaction.KeyregTxn)):
             return False
-        return (super(KeyregTxn, self).__eq__(self, other) and
-                self.votepk == other.votepk and
-                self.selkey == other.selkey and
-                self.votefst == other.votefst and
-                self.votelst == other.votelst and
-                self.votekd == other.votekd)
+        return (
+            super(KeyregTxn, self).__eq__(self, other)
+            and self.votepk == other.votepk
+            and self.selkey == other.selkey
+            and self.votefst == other.votefst
+            and self.votelst == other.votelst
+            and self.votekd == other.votekd
+        )
 
 
 class AssetConfigTxn(Transaction):
@@ -377,7 +448,7 @@ class AssetConfigTxn(Transaction):
 
     Args:
         sender (str): address of the sender
-        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true, 
+        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true,
             fee may fall to zero but a group of N atomic transactions must
             still have a fee of at least N*min_txn_fee.
         first (int): first round for which the transaction is valid
@@ -443,14 +514,45 @@ class AssetConfigTxn(Transaction):
         rekey_to (str)
     """
 
-    def __init__(self, sender, fee, first, last, gh, index=None,
-                 total=None, default_frozen=None, unit_name=None,
-                 asset_name=None, manager=None, reserve=None,
-                 freeze=None, clawback=None, url=None, metadata_hash=None,
-                 note=None, gen=None, flat_fee=False, lease=None,
-                 strict_empty_address_check=True, decimals=0, rekey_to=None):
-        Transaction.__init__(self,  sender, fee, first, last, note, gen, gh,
-                             lease, constants.assetconfig_txn, rekey_to)
+    def __init__(
+        self,
+        sender,
+        fee,
+        first,
+        last,
+        gh,
+        index=None,
+        total=None,
+        default_frozen=None,
+        unit_name=None,
+        asset_name=None,
+        manager=None,
+        reserve=None,
+        freeze=None,
+        clawback=None,
+        url=None,
+        metadata_hash=None,
+        note=None,
+        gen=None,
+        flat_fee=False,
+        lease=None,
+        strict_empty_address_check=True,
+        decimals=0,
+        rekey_to=None,
+    ):
+        Transaction.__init__(
+            self,
+            sender,
+            fee,
+            first,
+            last,
+            note,
+            gen,
+            gh,
+            lease,
+            constants.assetconfig_txn,
+            rekey_to,
+        )
         if strict_empty_address_check:
             if not (manager and reserve and freeze and clawback):
                 raise error.EmptyAddressError
@@ -472,15 +574,24 @@ class AssetConfigTxn(Transaction):
             if len(metadata_hash) != constants.metadata_length:
                 raise error.WrongMetadataLengthError
         if not flat_fee:
-            self.fee = max(self.estimate_size()*self.fee,
-                           constants.min_txn_fee)
+            self.fee = max(
+                self.estimate_size() * self.fee, constants.min_txn_fee
+            )
 
     def dictify(self):
         d = dict()
 
-        if (self.total or self.default_frozen or self.unit_name or
-                self.asset_name or self.manager or self.reserve or
-                self.freeze or self.clawback or self.decimals):
+        if (
+            self.total
+            or self.default_frozen
+            or self.unit_name
+            or self.asset_name
+            or self.manager
+            or self.reserve
+            or self.freeze
+            or self.clawback
+            or self.decimals
+        ):
             apar = OrderedDict()
             if self.metadata_hash:
                 apar["am"] = self.metadata_hash
@@ -568,29 +679,31 @@ class AssetConfigTxn(Transaction):
             "url": url,
             "metadata_hash": metadata_hash,
             "strict_empty_address_check": False,
-            "decimals": decimals
+            "decimals": decimals,
         }
 
         return args
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                AssetConfigTxn,
-                future.transaction.AssetConfigTxn)):
+        if not isinstance(
+            other, (AssetConfigTxn, future.transaction.AssetConfigTxn)
+        ):
             return False
-        return (super(AssetConfigTxn, self).__eq__(other) and
-                self.index == other.index and
-                self.total == other.total and
-                self.default_frozen == other.default_frozen and
-                self.unit_name == other.unit_name and
-                self.asset_name == other.asset_name and
-                self.manager == other.manager and
-                self.reserve == other.reserve and
-                self.freeze == other.freeze and
-                self.clawback == other.clawback and
-                self.url == other.url and
-                self.metadata_hash == other.metadata_hash and
-                self.decimals == other.decimals)
+        return (
+            super(AssetConfigTxn, self).__eq__(other)
+            and self.index == other.index
+            and self.total == other.total
+            and self.default_frozen == other.default_frozen
+            and self.unit_name == other.unit_name
+            and self.asset_name == other.asset_name
+            and self.manager == other.manager
+            and self.reserve == other.reserve
+            and self.freeze == other.freeze
+            and self.clawback == other.clawback
+            and self.url == other.url
+            and self.metadata_hash == other.metadata_hash
+            and self.decimals == other.decimals
+        )
 
 
 class AssetFreezeTxn(Transaction):
@@ -601,7 +714,7 @@ class AssetFreezeTxn(Transaction):
     Args:
         sender (str): address of the sender, who must be the asset's freeze
             manager
-        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true, 
+        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true,
             fee may fall to zero but a group of N atomic transactions must
             still have a fee of at least N*min_txn_fee.
         first (int): first round for which the transaction is valid
@@ -635,18 +748,42 @@ class AssetFreezeTxn(Transaction):
         rekey_to (str)
     """
 
-    def __init__(self, sender, fee, first, last, gh, index, target,
-                 new_freeze_state, note=None, gen=None, flat_fee=False,
-                 lease=None, rekey_to=None):
-        Transaction.__init__(self, sender, fee, first, last, note, gen, gh,
-                             lease, constants.assetfreeze_txn, rekey_to)
+    def __init__(
+        self,
+        sender,
+        fee,
+        first,
+        last,
+        gh,
+        index,
+        target,
+        new_freeze_state,
+        note=None,
+        gen=None,
+        flat_fee=False,
+        lease=None,
+        rekey_to=None,
+    ):
+        Transaction.__init__(
+            self,
+            sender,
+            fee,
+            first,
+            last,
+            note,
+            gen,
+            gh,
+            lease,
+            constants.assetfreeze_txn,
+            rekey_to,
+        )
         self.index = index
         self.target = target
         self.new_freeze_state = new_freeze_state
         if not flat_fee:
-            self.fee = max(self.estimate_size()*self.fee,
-                           constants.min_txn_fee)
-            
+            self.fee = max(
+                self.estimate_size() * self.fee, constants.min_txn_fee
+            )
 
     def dictify(self):
         d = dict()
@@ -667,20 +804,22 @@ class AssetFreezeTxn(Transaction):
         args = {
             "index": d["faid"],
             "new_freeze_state": d["afrz"] if "afrz" in d else False,
-            "target": encoding.encode_address(d["fadd"])
+            "target": encoding.encode_address(d["fadd"]),
         }
 
         return args
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                AssetFreezeTxn,
-                future.transaction.AssetFreezeTxn)):
+        if not isinstance(
+            other, (AssetFreezeTxn, future.transaction.AssetFreezeTxn)
+        ):
             return False
-        return (super(AssetFreezeTxn, self).__eq__(other) and
-                self.index == other.index and
-                self.target == other.target and
-                self.new_freeze_state == other.new_freeze_state)
+        return (
+            super(AssetFreezeTxn, self).__eq__(other)
+            and self.index == other.index
+            and self.target == other.target
+            and self.new_freeze_state == other.new_freeze_state
+        )
 
 
 class AssetTransferTxn(Transaction):
@@ -693,7 +832,7 @@ class AssetTransferTxn(Transaction):
 
     Args:
         sender (str): address of the sender
-        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true, 
+        fee (int): transaction fee (per byte if flat_fee is false). When flat_fee is true,
             fee may fall to zero but a group of N atomic transactions must
             still have a fee of at least N*min_txn_fee.
         first (int): first round for which the transaction is valid
@@ -733,11 +872,37 @@ class AssetTransferTxn(Transaction):
         rekey_to (str)
     """
 
-    def __init__(self, sender, fee, first, last, gh, receiver, amt, index,
-                 close_assets_to=None, revocation_target=None, note=None,
-                 gen=None, flat_fee=False, lease=None, rekey_to=None):
-        Transaction.__init__(self,  sender, fee, first, last, note, gen, gh,
-                             lease, constants.assettransfer_txn, rekey_to)
+    def __init__(
+        self,
+        sender,
+        fee,
+        first,
+        last,
+        gh,
+        receiver,
+        amt,
+        index,
+        close_assets_to=None,
+        revocation_target=None,
+        note=None,
+        gen=None,
+        flat_fee=False,
+        lease=None,
+        rekey_to=None,
+    ):
+        Transaction.__init__(
+            self,
+            sender,
+            fee,
+            first,
+            last,
+            note,
+            gen,
+            gh,
+            lease,
+            constants.assettransfer_txn,
+            rekey_to,
+        )
         if receiver:
             self.receiver = receiver
         else:
@@ -749,8 +914,9 @@ class AssetTransferTxn(Transaction):
         self.close_assets_to = close_assets_to
         self.revocation_target = revocation_target
         if not flat_fee:
-            self.fee = max(self.estimate_size()*self.fee,
-                           constants.min_txn_fee)
+            self.fee = max(
+                self.estimate_size() * self.fee, constants.min_txn_fee
+            )
 
     def dictify(self):
         d = dict()
@@ -759,7 +925,7 @@ class AssetTransferTxn(Transaction):
             d["aamt"] = self.amount
         if self.close_assets_to:
             d["aclose"] = encoding.decode_address(self.close_assets_to)
-        
+
         decoded_receiver = encoding.decode_address(self.receiver)
         if any(decoded_receiver):
             d["arcv"] = encoding.decode_address(self.receiver)
@@ -778,29 +944,34 @@ class AssetTransferTxn(Transaction):
     @staticmethod
     def _undictify(d):
         args = {
-            "receiver": encoding.encode_address(
-                d["arcv"]) if "arcv" in d else None,
+            "receiver": encoding.encode_address(d["arcv"])
+            if "arcv" in d
+            else None,
             "amt": d["aamt"] if "aamt" in d else 0,
             "index": d["xaid"] if "xaid" in d else None,
-            "close_assets_to": encoding.encode_address(
-                d["aclose"]) if "aclose" in d else None,
-            "revocation_target": encoding.encode_address(
-                d["asnd"]) if "asnd" in d else None
+            "close_assets_to": encoding.encode_address(d["aclose"])
+            if "aclose" in d
+            else None,
+            "revocation_target": encoding.encode_address(d["asnd"])
+            if "asnd" in d
+            else None,
         }
 
         return args
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                AssetTransferTxn,
-                future.transaction.AssetTransferTxn)):
+        if not isinstance(
+            other, (AssetTransferTxn, future.transaction.AssetTransferTxn)
+        ):
             return False
-        return (super(AssetTransferTxn, self).__eq__(other) and
-                self.index == other.index and
-                self.amount == other.amount and
-                self.receiver == other.receiver and
-                self.close_assets_to == other.close_assets_to and
-                self.revocation_target == other.revocation_target)
+        return (
+            super(AssetTransferTxn, self).__eq__(other)
+            and self.index == other.index
+            and self.amount == other.amount
+            and self.receiver == other.receiver
+            and self.close_assets_to == other.close_assets_to
+            and self.revocation_target == other.revocation_target
+        )
 
 
 class SignedTransaction:
@@ -817,6 +988,7 @@ class SignedTransaction:
         signature (str)
         authorizing_address (str)
     """
+
     def __init__(self, transaction, signature, authorizing_address=None):
         self.signature = signature
         self.transaction = transaction
@@ -844,13 +1016,15 @@ class SignedTransaction:
         return stx
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                SignedTransaction,
-                future.transaction.SignedTransaction)):
+        if not isinstance(
+            other, (SignedTransaction, future.transaction.SignedTransaction)
+        ):
             return False
-        return (self.transaction == other.transaction and
-                self.signature == other.signature and
-                self.authorizing_address == other.authorizing_address)
+        return (
+            self.transaction == other.transaction
+            and self.signature == other.signature
+            and self.authorizing_address == other.authorizing_address
+        )
 
 
 class MultisigTransaction:
@@ -865,6 +1039,7 @@ class MultisigTransaction:
         transaction (Transaction)
         multisig (Multisig)
     """
+
     def __init__(self, transaction, multisig):
         self.transaction = transaction
         self.multisig = multisig
@@ -889,7 +1064,7 @@ class MultisigTransaction:
             raise error.BadTxnSenderError
         index = -1
         public_key = base64.b64decode(bytes(private_key, "utf-8"))
-        public_key = public_key[constants.key_len_bytes:]
+        public_key = public_key[constants.key_len_bytes :]
         for s in range(len(self.multisig.subsigs)):
             if self.multisig.subsigs[s].public_key == public_key:
                 index = s
@@ -946,20 +1121,26 @@ class MultisigTransaction:
                 for s in range(len(stx.multisig.subsigs)):
                     if stx.multisig.subsigs[s].signature:
                         if not msigstx.multisig.subsigs[s].signature:
-                            msigstx.multisig.subsigs[s].signature = \
-                                stx.multisig.subsigs[s].signature
-                        elif not msigstx.multisig.subsigs[s].signature == \
-                                stx.multisig.subsigs[s].signature:
+                            msigstx.multisig.subsigs[
+                                s
+                            ].signature = stx.multisig.subsigs[s].signature
+                        elif (
+                            not msigstx.multisig.subsigs[s].signature
+                            == stx.multisig.subsigs[s].signature
+                        ):
                             raise error.DuplicateSigMismatchError
         return msigstx
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                MultisigTransaction,
-                future.transaction.MultisigTransaction)):
+        if not isinstance(
+            other,
+            (MultisigTransaction, future.transaction.MultisigTransaction),
+        ):
             return False
-        return (self.transaction == other.transaction and
-                self.multisig == other.multisig)
+        return (
+            self.transaction == other.transaction
+            and self.multisig == other.multisig
+        )
 
 
 class Multisig:
@@ -976,6 +1157,7 @@ class Multisig:
         threshold (int)
         subsigs (MultisigSubsig[])
     """
+
     def __init__(self, version, threshold, addresses):
         self.version = version
         self.threshold = threshold
@@ -987,16 +1169,22 @@ class Multisig:
         """Check if the multisig account is valid."""
         if not self.version == 1:
             raise error.UnknownMsigVersionError
-        if (self.threshold <= 0 or len(self.subsigs) == 0 or
-                self.threshold > len(self.subsigs)):
+        if (
+            self.threshold <= 0
+            or len(self.subsigs) == 0
+            or self.threshold > len(self.subsigs)
+        ):
             raise error.InvalidThresholdError
         if len(self.subsigs) > constants.multisig_account_limit:
             raise error.MultisigAccountSizeError
 
     def address(self):
         """Return the multisig account address."""
-        msig_bytes = (bytes(constants.msig_addr_prefix, "utf-8") +
-                      bytes([self.version]) + bytes([self.threshold]))
+        msig_bytes = (
+            bytes(constants.msig_addr_prefix, "utf-8")
+            + bytes([self.version])
+            + bytes([self.threshold])
+        )
         for s in self.subsigs:
             msig_bytes += s.public_key
         addr = encoding.checksum(msig_bytes)
@@ -1038,7 +1226,7 @@ class Multisig:
         d = {
             "subsig": [subsig.json_dictify() for subsig in self.subsigs],
             "thr": self.threshold,
-            "v": self.version
+            "v": self.version,
         }
         return d
 
@@ -1062,13 +1250,13 @@ class Multisig:
         return pks
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                Multisig,
-                future.transaction.Multisig)):
+        if not isinstance(other, (Multisig, future.transaction.Multisig)):
             return False
-        return (self.version == other.version and
-                self.threshold == other.threshold and
-                self.subsigs == other.subsigs)
+        return (
+            self.version == other.version
+            and self.threshold == other.threshold
+            and self.subsigs == other.subsigs
+        )
 
 
 class MultisigSubsig:
@@ -1077,6 +1265,7 @@ class MultisigSubsig:
         public_key (bytes)
         signature (bytes)
     """
+
     def __init__(self, public_key, signature=None):
         self.public_key = public_key
         self.signature = signature
@@ -1089,9 +1278,7 @@ class MultisigSubsig:
         return od
 
     def json_dictify(self):
-        d = {
-            "pk": base64.b64encode(self.public_key).decode()
-        }
+        d = {"pk": base64.b64encode(self.public_key).decode()}
         if self.signature:
             d["s"] = base64.b64encode(self.signature).decode()
         return d
@@ -1105,12 +1292,14 @@ class MultisigSubsig:
         return mss
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                MultisigSubsig,
-                future.transaction.MultisigSubsig)):
+        if not isinstance(
+            other, (MultisigSubsig, future.transaction.MultisigSubsig)
+        ):
             return False
-        return (self.public_key == other.public_key and
-                self.signature == other.signature)
+        return (
+            self.public_key == other.public_key
+            and self.signature == other.signature
+        )
 
 
 class LogicSig:
@@ -1153,7 +1342,7 @@ class LogicSig:
         if "sig" in d:
             lsig.sig = base64.b64encode(d["sig"]).decode()
         elif "msig" in d:
-            lsig.msig = Multisig.undictify(d['msig'])
+            lsig.msig = Multisig.undictify(d["msig"])
         return lsig
 
     def verify(self, public_key):
@@ -1205,7 +1394,7 @@ class LogicSig:
     @staticmethod
     def sign_program(program, private_key):
         private_key = base64.b64decode(private_key)
-        signing_key = SigningKey(private_key[:constants.key_len_bytes])
+        signing_key = SigningKey(private_key[: constants.key_len_bytes])
         to_sign = constants.logic_prefix + program
         signed = signing_key.sign(to_sign)
         return base64.b64encode(signed.signature).decode()
@@ -1214,7 +1403,7 @@ class LogicSig:
     def single_sig_multisig(program, private_key, multisig):
         index = -1
         public_key = base64.b64decode(bytes(private_key, "utf-8"))
-        public_key = public_key[constants.key_len_bytes:]
+        public_key = public_key[constants.key_len_bytes :]
         for s in range(len(multisig.subsigs)):
             if multisig.subsigs[s].public_key == public_key:
                 index = s
@@ -1242,8 +1431,9 @@ class LogicSig:
         if not multisig:
             self.sig = LogicSig.sign_program(self.logic, private_key)
         else:
-            sig, index = LogicSig.single_sig_multisig(self.logic, private_key,
-                                                      multisig)
+            sig, index = LogicSig.single_sig_multisig(
+                self.logic, private_key, multisig
+            )
             multisig.subsigs[index].signature = base64.b64decode(sig)
             self.msig = multisig
 
@@ -1261,19 +1451,20 @@ class LogicSig:
 
         if self.msig is None:
             raise error.InvalidSecretKeyError
-        sig, index = LogicSig.single_sig_multisig(self.logic, private_key,
-                                                  self.msig)
+        sig, index = LogicSig.single_sig_multisig(
+            self.logic, private_key, self.msig
+        )
         self.msig.subsigs[index].signature = base64.b64decode(sig)
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                LogicSig,
-                future.transaction.LogicSig)):
+        if not isinstance(other, (LogicSig, future.transaction.LogicSig)):
             return False
-        return (self.logic == other.logic and
-                self.args == other.args and
-                self.sig == other.sig and
-                self.msig == other.msig)
+        return (
+            self.logic == other.logic
+            and self.args == other.args
+            and self.sig == other.sig
+            and self.msig == other.msig
+        )
 
 
 class LogicSigTransaction:
@@ -1322,12 +1513,14 @@ class LogicSigTransaction:
         return lstx
 
     def __eq__(self, other):
-        if not isinstance(other, (
-                LogicSigTransaction,
-                future.transaction.LogicSigTransaction)):
+        if not isinstance(
+            other,
+            (LogicSigTransaction, future.transaction.LogicSigTransaction),
+        ):
             return False
-        return (self.lsig == other.lsig and
-                self.transaction == other.transaction)
+        return (
+            self.lsig == other.lsig and self.transaction == other.transaction
+        )
 
 
 def write_to_file(objs, path, overwrite=True):
@@ -1364,7 +1557,11 @@ def write_to_file(objs, path, overwrite=True):
 
     for obj in objs:
         if isinstance(obj, Transaction):
-            f.write(base64.b64decode(encoding.msgpack_encode({"txn": obj.dictify()})))
+            f.write(
+                base64.b64decode(
+                    encoding.msgpack_encode({"txn": obj.dictify()})
+                )
+            )
         else:
             f.write(base64.b64decode(encoding.msgpack_encode(obj)))
 
@@ -1462,4 +1659,4 @@ def assign_group_id(txns, address=None):
         if address is None or tx.sender == address:
             tx.group = gid
             result.append(tx)
-    return result
\ No newline at end of file
+    return result
