@@ -1,36 +1,35 @@
 import base64
 import json
 import os
-import urllib
 import unittest
+import urllib
 from datetime import datetime
 from pathlib import Path
 from urllib.request import Request, urlopen
 
-from behave import (
-    given,
-    when,
-    then,
-    register_type,
-    step,
-)  # pylint: disable=no-name-in-module
-
-from glom import glom
 import parse
-
-from algosdk import dryrun_results, encoding, error, mnemonic, source_map
+from algosdk import (
+    dryrun_results,
+    encoding,
+    error,
+    mnemonic,
+    source_map,
+)
 from algosdk.error import AlgodHTTPError
 from algosdk.future import transaction
+from algosdk.testing.dryrun import DryrunTestCaseMixin
 from algosdk.v2client import *
 from algosdk.v2client.models import (
-    DryrunRequest,
-    DryrunSource,
     Account,
     ApplicationLocalState,
+    DryrunRequest,
+    DryrunSource,
 )
-from algosdk.testing.dryrun import DryrunTestCaseMixin
-
-from tests.steps.steps import algod_port, token as daemon_token
+from behave import register_type  # pylint: disable=no-name-in-module
+from behave import given, step, then, when
+from glom import glom
+from tests.steps.steps import algod_port
+from tests.steps.steps import token as daemon_token
 
 
 @parse.with_pattern(r".*")
